#' Run time data
#'
#' Run times measured on an Intel(R) Xeon(R) CPU X5680 clocked at 3.33 GHz
#' with 12 MB cache, running RedHat Enterprise Linux, R 3.2.3 and gcc 4.8.5,
#' using version 0.4 of the \code{wrswoR} package.
#' The data are created by the corresponding scripts in the \code{data_raw}
#' directory.
#'
#' @details \code{timings} contains run times for a larger range of values
#'   for the \code{n} argument.
#'
#' @name timings
#' @export
#' @examples
#' head(timings)
NULL

#' @rdname timings
#'
#' @details \code{timings_sort} contains run times for sorting probabilities
#'   with the given distributions.
#'
#' @export
"timings_sort"
